==> com_clubmanagement_1.1.zip: site/router.php <==
<?php
function ClubmanagementBuildRoute( &$query )
{
	$segments = array();
//echo "<pre>";
if (isset($query['view']) && isset($query['layout'])) {
	unset($query['Itemid']);
	$option = "com_clubmanagement";
	$layout = $query['layout'];
	unset($query['layout']);
	$view = $query['view'];
	unset($query['view']);
//$segments[] = $view;
//$segments[] = $layout;
} else {

	$menu = &JSite::getMenu();
	if (empty($query['Itemid'])) {
		$menuItem = &$menu->getActive();
	} else {
		$menuItem = &$menu->getItem($query['Itemid']);
	}
	$option = (empty($menuItem->query['option'])) ? null : $menuItem->query['option'];
	$view = (empty($menuItem->query['view'])) ? null : $menuItem->query['view'];
	$layout = (empty($menuItem->query['layout'])) ? null : $menuItem->query['layout'];
	//unset($query['view']);
	//unset($menuItem->query['layout']);
	//unset($menuItem->query['view']);
	//unset($menuItem->query['option']);
	//unset($query['layout']);
//print_r($query);
//print_r($menuItem);
//print_r($segments);
	//unset($query['Itemid']);
}
//echo "</pre>";
$segments[] = $view;
$segments[] = $layout;
//print_r($_REQUEST);
//return $segments;

	switch( $view )
	{
		case 'memberstatistics':
		break;
		case 'members':
			require_once(JPATH_ROOT.DS."components".DS."com_clubmanagement".DS.'models'.DS.'people.php' );
			$model = & JModel::getInstance('people','ClubmanagementModel');
			$params = &JComponentHelper::getParams( 'com_clubmanagement' );
			$params->merge( new JParameter( &$menuItem->params ) );
			switch($layout) {
				case "personalfactsheet":
					$id = (empty($menuItem->query['people_id'])) ? $query['people_id'] : $menuItem->query['people_id'];
					unset($query['people_id']);
					$people = $model->getPersonalData($id);
					$segments[] = JFilterOutput::stringURLSafe($people->people_id."-".$people->name."-".$people->surname);
				break;
				case "sectionmembers":
					$id = (empty($menuItem->query['section_id'])) ? $query['section_id'] : $menuItem->query['section_id'];
					unset($query['section_id']);
					require_once(JPATH_ROOT.DS."administrator".DS."components".DS."com_clubmanagement".DS.'models'.DS.'sections.php' );
					$model = & JModel::getInstance('sections','ClubmanagementModel');
					$section = $model->getData($id);
					$section=$section[0];
					$segments[] = JFilterOutput::stringURLSafe($section->value."-".$section->text);#."-".JText::_('COM_CLUBMANAGEMENT_MEMBER')
				break;
			}
		break;
	}
	return $segments;
}

function ClubmanagementParseRoute( $segments )
{
	$vars = array();
$vars['view'] = array_shift($segments);
$vars['layout'] = array_shift($segments);
	//echo $vars['view'];
	switch($vars['view'])
	{
		case 'memberstatistics':
		break;
		case 'members':
			//switch($layout) {
			switch($vars['layout']) {
				case "personalfactsheet":
					require_once(JPATH_ROOT.DS."components".DS."com_clubmanagement".DS.'models'.DS.'people.php' );
					if(count($segments)==0 || !is_array($segments)) {return FALSE;}
					$tmp = explode(":", $segments[0]);
					
					//if(count($tmp)<2 || !is_array($tmp)) {return FALSE;}
					$people_id = $tmp[0];
					$model = & JModel::getInstance('people','ClubmanagementModel');
					$people = $model->getPersonalData($people_id);
					if(JFilterOutput::stringURLSafe($people->name."-".$people->surname)!=$tmp[1] && count($tmp)>1) {
						$msg=JText::sprintf('COM_CLUBMANAGEMENT_ERROR_PERSON_UNKNOWN', 'hallo');
						JError::raiseWarning( 404, $msg );
					}
					$vars['people_id'] = $people_id;
				break;
				case "sectionmembers":
					if(count($segments)==0 || !is_array($segments)) {return FALSE;}
					$tmp = explode(":", $segments[0]);
					if(count($tmp)<2 || !is_array($tmp)) {return FALSE;}
					$section_id = $tmp[0];
	
					require_once(JPATH_ROOT.DS."administrator".DS."components".DS."com_clubmanagement".DS.'models'.DS.'sections.php' );
					$model = & JModel::getInstance('sections','ClubmanagementModel');
					$section = $model->getData($section_id);
					if(JFilterOutput::stringURLSafe($section[0]->text)!=$tmp[1]) {
						$msg=JText::_('COM_CLUBMANAGEMENT_ERROR_SECTION_UNKNOWN');
						JError::raiseWarning( 404, $msg );
					}
					$vars['section_id'] = $section_id;
				break;
			}
		break;
	}

	return $vars;
}

==> com_clubmanagement_1.3.zip: site/router.php <==
<?php
jimport( 'joomla.html.parameter' );
function ClubmanagementBuildRoute( &$query )
{
	$segments = array();
//echo "<pre>";
if (isset($query['view']) && isset($query['layout'])) {
	unset($query['Itemid']);
	$option = "com_clubmanagement";
	$layout = $query['layout'];
	unset($query['layout']);
	$view = $query['view'];
	unset($query['view']);
//$segments[] = $view;
//$segments[] = $layout;
} else {

	$menu = &JSite::getMenu();
	if (empty($query['Itemid'])) {
		$menuItem = &$menu->getActive();
	} else {
		$menuItem = &$menu->getItem($query['Itemid']);
	}
	$option = (empty($menuItem->query['option'])) ? null : $menuItem->query['option'];
	$view = (empty($menuItem->query['view'])) ? null : $menuItem->query['view'];
	$layout = (empty($menuItem->query['layout'])) ? null : $menuItem->query['layout'];
}
$segments[] = $view;
$segments[] = $layout;

	switch( $view )
	{
		case 'memberstatistics':
		break;
		case 'members':
			require_once(JPATH_ROOT.DS."components".DS."com_clubmanagement".DS.'models'.DS.'people.php' );
			$model = JModel::getInstance('people','ClubmanagementModel');
			$params = JComponentHelper::getParams( 'com_clubmanagement' );
			$params->merge( new JParameter( $menuItem->params ) );
			switch($layout) {
				case "personalfactsheet":
					$id = (empty($menuItem->query['people_id'])) ? $query['people_id'] : $menuItem->query['people_id'];
					unset($query['people_id']);
					$people = $model->getPersonalData($id);
					$segments[] = JFilterOutput::stringURLSafe($people->people_id."-".$people->name."-".$people->surname);
				break;
				case "sectionmembers":
					$id = (empty($menuItem->query['section_id'])) ? $query['section_id'] : $menuItem->query['section_id'];
					unset($query['section_id']);
					require_once(JPATH_ROOT.DS."administrator".DS."components".DS."com_clubmanagement".DS.'models'.DS.'sections.php' );
					$model = & JModel::getInstance('sections','ClubmanagementModel');
					$section = $model->getData($id);
					$section=$section[0];
					$segments[] = JFilterOutput::stringURLSafe($section->value."-".$section->text);#."-".JText::_('COM_CLUBMANAGEMENT_MEMBER')
				break;
			}
		break;
	}
	return $segments;
}

function ClubmanagementParseRoute( $segments )
{
	$vars = array();
$vars['view'] = array_shift($segments);
$vars['layout'] = array_shift($segments);
	//echo $vars['view'];
	switch($vars['view'])
	{
		case 'memberstatistics':
		break;
		case 'members':
			//switch($layout) {
			switch($vars['layout']) {
				case "personalfactsheet":
					require_once(JPATH_ROOT.DS."components".DS."com_clubmanagement".DS.'models'.DS.'people.php' );
					if(count($segments)==0 || !is_array($segments)) {return FALSE;}
					$tmp = explode(":", $segments[0]);
					
					//if(count($tmp)<2 || !is_array($tmp)) {return FALSE;}
					$people_id = $tmp[0];
					$model = JModel::getInstance('people','ClubmanagementModel');
					$people = $model->getPersonalData($people_id);
					if(JFilterOutput::stringURLSafe($people->name."-".$people->surname)!=$tmp[1] && count($tmp)>1) {
						$msg=JText::sprintf('COM_CLUBMANAGEMENT_ERROR_PERSON_UNKNOWN', 'hallo');
						JError::raiseWarning( 404, $msg );
					}
					$vars['people_id'] = $people_id;
				break;
				case "sectionmembers":
					if(count($segments)==0 || !is_array($segments)) {return FALSE;}
					$tmp = explode(":", $segments[0]);
					if(count($tmp)<2 || !is_array($tmp)) {return FALSE;}
					$section_id = $tmp[0];
	
					require_once(JPATH_ROOT.DS."administrator".DS."components".DS."com_clubmanagement".DS.'models'.DS.'sections.php' );
					$model = & JModel::getInstance('sections','ClubmanagementModel');
					$section = $model->getData($section_id);
					if(JFilterOutput::stringURLSafe($section[0]->text)!=$tmp[1]) {
						$msg=JText::_('COM_CLUBMANAGEMENT_ERROR_SECTION_UNKNOWN');
						JError::raiseWarning( 404, $msg );
					}
					$vars['section_id'] = $section_id;
				break;
			}
		break;
	}

	return $vars;
}
